.. include:: ../README.rst


DP_epidemiology documentation
=============================

.. Add your content using ``reStructuredText`` syntax. See the
.. `reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
.. documentation for details.
**DP_epidemiology** is a Python library which hosts tool for differential private release of financial data in the context of epidemiology. It is built on top of the `OpenDP <https://opendp.org/>`_ library
and offers a *simple* and *intuitive* API.

Check out the :doc:`usage` section for further information, including
how to :ref:`installation` the project.


.. note::

   This project is under active development.

Contents
--------

.. toctree::

   Home <self>
   usage
   api